==> react-native-bugsee-5.5.0.tgz: package/android/src/oldarch/java/com/bugsee/BugseeNativeBridge.java <==
package com.bugsee;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import androidx.annotation.NonNull;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.Promise;
import com.facebook.react.modules.network.OkHttpClientFactory;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class BugseeNativeBridge extends ReactContextBaseJavaModule {
    private final BugseeNativeBridgeImpl impl;

    public BugseeNativeBridge(ReactApplicationContext reactContext) {
        super(reactContext);

        impl = new BugseeNativeBridgeImpl(reactContext);
    }

    public static OkHttpClientFactory getDefaultHttpFactory() {
        return BugseeNativeBridgeImpl.getDefaultHttpFactory();
    }

    @Override
    public String getName() {
        return BugseeNativeBridgeImpl.NAME;
    }

    @ReactMethod
    public void setFlag(String flagName, boolean flagState) {
        this.impl.setFlag(flagName, flagState);
    }

    @ReactMethod
    public void launch(String appToken, ReadableMap options, Promise promise) {
        this.impl.launch(appToken, options, promise);
    }

    @ReactMethod
    public void stop(Promise promise) {
        this.impl.stop(promise);
    }

    @ReactMethod
    public void relaunch(ReadableMap options, Promise promise) {
        this.impl.relaunch(options, promise);
    }

    @ReactMethod
    public void log(ReadableMap payload) {
        this.impl.log(payload);
    }

    @ReactMethod
    public void event(ReadableMap payload) {
        this.impl.event(payload);
    }

    @ReactMethod
    public void trace(ReadableMap payload) {
        this.impl.trace(payload);
    }

    @ReactMethod
    public void pause() {
        this.impl.pause();
    }

    @ReactMethod
    public void resume() {
        this.impl.resume();
    }

    @ReactMethod
    public void toggleProtected(double viewId, boolean isProtected) {
        this.impl.toggleProtected((int) viewId, isProtected);
    }

    @ReactMethod
    public void showReportDialog(ReadableMap payload) {
        this.impl.showReportDialog(payload);
    }

    @ReactMethod
    public void upload(ReadableMap payload) {
        this.impl.upload(payload);
    }

    @ReactMethod
    public void setEmail(ReadableMap payload) {
        this.impl.setEmail(payload);
    }

    @ReactMethod
    public void clearEmail() {
        this.impl.setEmail(null);
    }

    @ReactMethod
    public void getEmail(Promise promise) {
        this.impl.getEmail(promise);
    }

    @ReactMethod
    public void setAttribute(ReadableMap payload) {
        this.impl.setAttribute(payload);
    }

    @ReactMethod
    public void getAttribute(String name, Promise promise) {
        this.impl.getAttribute(name, promise);
    }

    @ReactMethod
    public void clearAttribute(ReadableMap payload) {
        this.impl.clearAttribute(payload);
    }

    @ReactMethod
    public void clearAllAttributes() {
        this.impl.clearAllAttributes();
    }

    @ReactMethod
    public void showFeedbackUI() {
        this.impl.showFeedbackUI();
    }

    @ReactMethod
    public void setDefaultFeedbackGreeting(String message) {
        this.impl.setDefaultFeedbackGreeting(message);
    }

    @ReactMethod
    public void logException(String exception, @Nullable Boolean isHandled, @Nullable ReadableMap options, Promise promise) {
        final boolean isHandledValue = isHandled != null ? isHandled : false;
        this.impl.logException(exceptionJson, isHandledValue, options, promise);
    }

    @ReactMethod
    public void deleteCollectedDataOnDevice(Promise promise) {
        this.impl.deleteCollectedDataOnDevice(promise);
    }

    @ReactMethod
    public void addSecureRect(double left, double top, double width, double height) {
        this.impl.addSecureRect((int) left, (int) top, (int) width, (int) height);
    }

    @ReactMethod
    public void removeSecureRect(double left, double top, double width, double height) {
        this.impl.removeSecureRect((int) left, (int) top, (int) width, (int) height);
    }

    @ReactMethod
    public void getAllSecureRects(Promise promise) {
        this.impl.getAllSecureRects(promise);
    }

    @ReactMethod
    public void removeAllSecureRects() {
        this.impl.removeAllSecureRects();
    }

    @ReactMethod
    public void getVersions(Promise promise) {
        this.impl.getVersions(promise);
    }

    @ReactMethod
    public void getLaunchOptions(final Promise promise) {
        this.impl.getLaunchOptions(promise);
    }

    @ReactMethod
    public void hideKeyboard(boolean isHidden) {
        // Just a mock
    }

    @ReactMethod
    public void logNetworkEvent(String networkJson) {
        this.impl.logNetworkEvent(networkJson);
    }

    @ReactMethod
    public void setAttachments(String attachmentsJson) {
        this.impl.setAttachments(attachmentsJson);
    }

    @ReactMethod
    public void getAppearanceProperty(String propertyName, Promise promise) {
        this.impl.getAppearanceProperty(propertyName, promise);
    }

    @ReactMethod
    public void setAppearanceProperty(ReadableMap appearanceData, Promise promise) {
        this.impl.setAppearanceProperty(appearanceData, promise);
    }

    @ReactMethod
    public void testCrash() {
        this.impl.testCrash();
    }

    @ReactMethod
    public void addListener(String eventName) {
        // Keep: Required for RN built in Event Emitter Calls.
    }

    @ReactMethod
    public void removeListeners(double count) {
        // Keep: Required for RN built in Event Emitter Calls.
    }

    @ReactMethod
    public void captureViewHierarchy() {
        this.impl.captureViewHierarchy();
    }
}

==> react-native-bugsee-5.5.2.tgz: package/android/src/oldarch/java/com/bugsee/BugseeNativeBridge.java <==
package com.bugsee;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import androidx.annotation.NonNull;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.Promise;
import com.facebook.react.modules.network.OkHttpClientFactory;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class BugseeNativeBridge extends ReactContextBaseJavaModule {
    private final BugseeNativeBridgeImpl impl;

    public BugseeNativeBridge(ReactApplicationContext reactContext) {
        super(reactContext);

        impl = new BugseeNativeBridgeImpl(reactContext);
    }

    public static OkHttpClientFactory getDefaultHttpFactory() {
        return BugseeNativeBridgeImpl.getDefaultHttpFactory();
    }

    @Override
    public String getName() {
        return BugseeNativeBridgeImpl.NAME;
    }

    @ReactMethod
    public void setFlag(String flagName, boolean flagState) {
        this.impl.setFlag(flagName, flagState);
    }

    @ReactMethod
    public void launch(String appToken, ReadableMap options, Promise promise) {
        this.impl.launch(appToken, options, promise);
    }

    @ReactMethod
    public void stop(Promise promise) {
        this.impl.stop(promise);
    }

    @ReactMethod
    public void relaunch(ReadableMap options, Promise promise) {
        this.impl.relaunch(options, promise);
    }

    @ReactMethod
    public void log(ReadableMap payload) {
        this.impl.log(payload);
    }

    @ReactMethod
    public void event(ReadableMap payload) {
        this.impl.event(payload);
    }

    @ReactMethod
    public void trace(ReadableMap payload) {
        this.impl.trace(payload);
    }

    @ReactMethod
    public void pause() {
        this.impl.pause();
    }

    @ReactMethod
    public void resume() {
        this.impl.resume();
    }

    @ReactMethod
    public void toggleProtected(double viewId, boolean isProtected) {
        this.impl.toggleProtected((int) viewId, isProtected);
    }

    @ReactMethod
    public void showReportDialog(ReadableMap payload) {
        this.impl.showReportDialog(payload);
    }

    @ReactMethod
    public void upload(ReadableMap payload) {
        this.impl.upload(payload);
    }

    @ReactMethod
    public void setEmail(ReadableMap payload) {
        this.impl.setEmail(payload);
    }

    @ReactMethod
    public void clearEmail() {
        this.impl.setEmail(null);
    }

    @ReactMethod
    public void getEmail(Promise promise) {
        this.impl.getEmail(promise);
    }

    @ReactMethod
    public void setAttribute(ReadableMap payload) {
        this.impl.setAttribute(payload);
    }

    @ReactMethod
    public void getAttribute(String name, Promise promise) {
        this.impl.getAttribute(name, promise);
    }

    @ReactMethod
    public void clearAttribute(ReadableMap payload) {
        this.impl.clearAttribute(payload);
    }

    @ReactMethod
    public void clearAllAttributes() {
        this.impl.clearAllAttributes();
    }

    @ReactMethod
    public void showFeedbackUI() {
        this.impl.showFeedbackUI();
    }

    @ReactMethod
    public void setDefaultFeedbackGreeting(String message) {
        this.impl.setDefaultFeedbackGreeting(message);
    }

    @ReactMethod
    public void logException(String exceptionJson, @Nullable Boolean isHandled, @Nullable ReadableMap options, Promise promise) {
        final boolean isHandledValue = isHandled != null ? isHandled : false;
        this.impl.logException(exceptionJson, isHandledValue, options, promise);
    }

    @ReactMethod
    public void deleteCollectedDataOnDevice(Promise promise) {
        this.impl.deleteCollectedDataOnDevice(promise);
    }

    @ReactMethod
    public void addSecureRect(double left, double top, double width, double height) {
        this.impl.addSecureRect((int) left, (int) top, (int) width, (int) height);
    }

    @ReactMethod
    public void removeSecureRect(double left, double top, double width, double height) {
        this.impl.removeSecureRect((int) left, (int) top, (int) width, (int) height);
    }

    @ReactMethod
    public void getAllSecureRects(Promise promise) {
        this.impl.getAllSecureRects(promise);
    }

    @ReactMethod
    public void removeAllSecureRects() {
        this.impl.removeAllSecureRects();
    }

    @ReactMethod
    public void getVersions(Promise promise) {
        this.impl.getVersions(promise);
    }

    @ReactMethod
    public void getLaunchOptions(final Promise promise) {
        this.impl.getLaunchOptions(promise);
    }

    @ReactMethod
    public void hideKeyboard(boolean isHidden) {
        // Just a mock
    }

    @ReactMethod
    public void logNetworkEvent(String networkJson) {
        this.impl.logNetworkEvent(networkJson);
    }

    @ReactMethod
    public void setAttachments(String attachmentsJson) {
        this.impl.setAttachments(attachmentsJson);
    }

    @ReactMethod
    public void getAppearanceProperty(String propertyName, Promise promise) {
        this.impl.getAppearanceProperty(propertyName, promise);
    }

    @ReactMethod
    public void setAppearanceProperty(ReadableMap appearanceData, Promise promise) {
        this.impl.setAppearanceProperty(appearanceData, promise);
    }

    @ReactMethod
    public void testCrash() {
        this.impl.testCrash();
    }

    @ReactMethod
    public void addListener(String eventName) {
        // Keep: Required for RN built in Event Emitter Calls.
    }

    @ReactMethod
    public void removeListeners(double count) {
        // Keep: Required for RN built in Event Emitter Calls.
    }

    @ReactMethod
    public void captureViewHierarchy() {
        this.impl.captureViewHierarchy();
    }
}
